### Hexlet tests and linter status:
[![Actions Status](https://github.com/Sterphius/python-project-49/workflows/hexlet-check/badge.svg)](https://github.com/Sterphius/python-project-49/actions)
[![Maintainability](https://api.codeclimate.com/v1/badges/032bf7df2200568ae9b6/maintainability)](https://codeclimate.com/github/Sterphius/python-project-49/maintainability)

## Description

This is the training project at Python Developer course at [Hexlet](hexlet.io). \
It contains five mathematic games:
- Brain-calc
- Brain-even
- Brain-gcd
- Brain-prime
- Brain-progression

## Install

You can install Brain Games, using [pip](https://pypi.org/project/pip/): \
`pip install sterphius-brain-games`
[![asciicast](https://asciinema.org/a/561422.svg)](https://asciinema.org/a/561422)

## Brain-calc

In this game you have to calculate result of the expression.
[![asciicast](https://asciinema.org/a/561428.svg)](https://asciinema.org/a/561428)

## Brain-even

In this game you have to answer whether the number is even or not.
[![asciicast](https://asciinema.org/a/561431.svg)](https://asciinema.org/a/561431)

## Brain-gcd

In this game it is required to find greatest common divider of 2 numbers.
[![asciicast](https://asciinema.org/a/561432.svg)](https://asciinema.org/a/561432)

## Brain-prime

In this game you have to tell if the number is prime or not.
[![asciicast](https://asciinema.org/a/561433.svg)](https://asciinema.org/a/561433)

## Brain-progression

In this game you have to fill in the missing number in arithmetic progression
[![asciicast](https://asciinema.org/a/561434.svg)](https://asciinema.org/a/561434)